#!/usr/bin/env python3
# Copyright (C) 2019 tribe29 GmbH - License: GNU General Public License v2
# This file is part of Checkmk (https://checkmk.com). It is subject to the terms and
# conditions defined in the file COPYING, which is part of this source code package.

# Argument 1: Full system path to the pnp4nagios index.php for fetching the graphs. Usually auto configured in OMD.
# Argument 2: HTTP-URL-Prefix to open Multisite. When provided, several links are added to the mail.
#             Example: http://myserv01/prod
#
# This script creates a nifty HTML email in multipart format with
# attached graphs and such neat stuff. Sweet!


from cmk.gui.plugins.wato.notifications import *



####Amazon SES Fields####
amazonsesfields = [
            (
                "amazonses",
                Transform(
                    Dictionary(
                        title="Send Mails with Amazon SES API",
                        elements=[
                            (
                                "sesapikey",
                                TextInput(
                                    title=_("Amazon API Key"),
                                    size=70,
                                    allow_empty=False,
                                ),
                            ),
                            (
                                "sesapipassword",
                                Password(
                                    title=_("Amazon API Password"),
                                    size=70,
                                    allow_empty=False,
                                ),
                            ),
                            (
                                "sesregion",
                                TextInput(
                                    title=_("AWS Region"),
                                    size=20,
                                    allow_empty=False,
                                    default_value="eu-central-1",
                                ),
                            ),
                            (
                                "sesconfig",
                                TextInput(
                                    title=_("SES Configuration Set"),
                                    size=20,
                                    allow_empty=True,
                                ),
                            ),                            
                        ],
                        help=_(
                            "All E-Mails will be Sent with the Amazon SES API"
                        ),
                    ),
                ),
            ),
]



@notification_parameter_registry.register
class NotificationParameterMail(NotificationParameter):
    @property
    def ident(self) -> str:
        return "mail"

    @property
    def spec(self):
        return Dictionary(
            title=_("Create notification with the following parameters"),
            # must be called at run time!!
            elements=self._parameter_elements_kpc,
        )

    def _parameter_elements_kpc(self):
        from cmk.gui.plugins.wato.notifications import _get_url_prefix_specs
        from cmk.gui.plugins.wato.notifications import _vs_add_common_mail_elements
        from cmk.gui.plugins.wato.notifications import local_site_url
        from cmk.gui.plugins.wato.notifications import transform_to_valuespec_html_mail_url_prefix
        from cmk.gui.plugins.wato.notifications import transform_from_valuespec_html_mail_url_prefix

        elements = _vs_add_common_mail_elements(
            [
                (
                    "elements",
                    ListChoice(
                        title=_("Display additional information"),
                        choices=[
                            ("omdsite", _("Site ID")),
                            ("hosttags", _("Tags of the Host")),
                            ("address", _("IP Address of Host")),
                            ("abstime", _("Absolute Time of Alert")),
                            ("reltime", _("Relative Time of Alert")),
                            ("longoutput", _("Additional Plugin Output")),
                            ("ack_author", _("Acknowledgement Author")),
                            ("ack_comment", _("Acknowledgement Comment")),
                            ("notification_author", _("Notification Author")),
                            ("notification_comment", _("Notification Comment")),
                            ("perfdata", _("Metrics")),
                            ("graph", _("Time series graph")),
                            ("notesurl", _("Custom Host/Service Notes URL")),
                            ("context", _("Complete variable list (for testing)")),
                        ],
                        default_value=["graph", "abstime", "address", "longoutput"],
                    ),
                ),
                (
                    "insert_html_section",
                    TextAreaUnicode(
                        title=_("Add HTML section above table (e.g. title, description…)"),
                        default_value="<HTMLTAG>CONTENT</HTMLTAG>",
                        cols=76,
                        rows=3,
                    ),
                ),
                (
                    "url_prefix",
                    _get_url_prefix_specs(
                        "http://" + socket.gethostname() + url_prefix() + "check_mk/",
                        request.is_ssl_request and "automatic_https" or "automatic_http",
                    ),
                ),
                (
                    "no_floating_graphs",
                    FixedValue(
                        value=True,
                        title=_("Display graphs among each other"),
                        totext=_("Graphs are shown among each other"),
                        help=_(
                            "By default all multiple graphs in emails are displayed floating "
                            "nearby. You can enable this option to show the graphs among each "
                            "other."
                        ),
                    ),
                ),
            ]
        )
        elements += amazonsesfields
        
        
        if not cmk_version.is_raw_edition():
            import cmk.gui.cee.plugins.wato.syncsmtp  # pylint: disable=no-name-in-module

            elements += cmk.gui.cee.plugins.wato.syncsmtp.cee_html_mail_smtp_sync_option


        elements += [
            (
                "graphs_per_notification",
                Integer(
                    title=_("Graphs per notification (default: 5)"),
                    label=_("Show up to"),
                    unit=_("graphs"),
                    help=_(
                        "Sets a limit for the number of graphs that are displayed in a notification."
                    ),
                    default_value=5,
                    minvalue=0,
                ),
            ),
            (
                "notifications_with_graphs",
                Integer(
                    title=_("Bulk notifications with graphs (default: 5)"),
                    label=_("Show graphs for the first"),
                    unit=_("Notifications"),
                    help=_(
                        "Sets a limit for the number of notifications in a bulk for which graphs "
                        "are displayed. If you do not use bulk notifications this option is ignored. "
                        "Note that each graph increases the size of the mail and takes time to render"
                        "on the monitoring server. Therefore, large bulks may exceed the maximum "
                        "size for attachements or the plugin may run into a timeout so that a failed "
                        "notification is produced."
                    ),
                    default_value=5,
                    minvalue=0,
                ),
            ),
        ]
        return elements
